@@ -5,8 +5,10 @@ import (
 	"fmt"
 	"os"
 	"os/exec"
+	"runtime"
 	"strings"
 
+	"github.com/Masterminds/semver/v3"
 	"github.com/hashicorp/go-version"
 	_ "github.com/jackc/pgx/v5/stdlib"
 	"github.com/turbot/go-kit/helpers"
@@ -16,15 +18,17 @@ import (
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
-var exitCode int
+var exitCode int = constants.ExitCodeSuccessful
 
 func main() {
 	ctx := context.Background()
 	utils.LogTime("main start")
-	exitCode := constants.ExitCodeSuccessful
 	defer func() {
 		if r := recover(); r != nil {
 			error_helpers.ShowError(ctx, helpers.ToError(r))
+			if exitCode == 0 {
+				exitCode = constants.ExitCodeUnknownErrorPanic
+			}
 		}
 		utils.LogTime("main end")
 		utils.DisplayProfileData()
@@ -37,6 +41,9 @@ func main() {
 	// ensure steampipe is not run on WSL1
 	checkWsl1(ctx)
 
+	// check OSX kernel version
+	checkOSXVersion(ctx)
+
 	cmd.InitCmd()
 
 	// execute the command
@@ -108,3 +115,35 @@ func checkWsl1(ctx context.Context) {
 		}
 	}
 }
+
+func checkOSXVersion(ctx context.Context) {
+	// get the OS and return if not darwin
+	if runtime.GOOS != "darwin" {
+		return
+	}
+
+	// get kernel version
+	output, err := exec.Command("uname", "-r").Output()
+	if err != nil {
+		error_helpers.ShowErrorWithMessage(ctx, err, "failed to get kernel version")
+		return
+	}
+
+	// get the semver version from string
+	version, err := semver.NewVersion(strings.TrimRight(string(output), "\n"))
+	if err != nil {
+		error_helpers.ShowErrorWithMessage(ctx, err, "failed to get version")
+		return
+	}
+	catalina, err := semver.NewVersion("19.0.0")
+	if err != nil {
+		error_helpers.ShowErrorWithMessage(ctx, err, "failed to get version")
+		return
+	}
+
+	// check if Darwin version is not less than Catalina(Darwin version 19.0.0)
+	if version.Compare(catalina) == -1 {
+		error_helpers.ShowError(ctx, fmt.Errorf("Steampipe requires MacOS 10.15 (Catalina) and above, please upgrade and try again."))
+		os.Exit(constants.ExitCodeInvalidExecutionEnvironment)
+	}
+}
