@@ -2,6 +2,7 @@ package modinstaller
 
 import (
 	"context"
+
 	"github.com/turbot/go-kit/helpers"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/utils"
@@ -17,7 +18,7 @@ func InstallWorkspaceDependencies(ctx context.Context, opts *InstallOpts) (_ *In
 	}()
 
 	// install workspace dependencies
-	installer, err := NewModInstaller(opts)
+	installer, err := NewModInstaller(ctx, opts)
 	if err != nil {
 		return nil, err
 	}
