@@ -2,9 +2,8 @@ package modconfig
 
 import (
 	"fmt"
-
 	"github.com/hashicorp/hcl/v2"
-	"github.com/turbot/steampipe/pkg/steampipeconfig/hclhelpers"
+	"github.com/turbot/go-kit/hcl_helpers"
 	"github.com/turbot/steampipe/pkg/utils"
 	"github.com/zclconf/go-cty/cty"
 )
@@ -40,7 +39,7 @@ func NewDashboardCategory(block *hcl.Block, mod *Mod, shortName string) HclResou
 				ShortName:       shortName,
 				FullName:        fullName,
 				UnqualifiedName: fmt.Sprintf("%s.%s", block.Type, shortName),
-				DeclRange:       hclhelpers.BlockRange(block),
+				DeclRange:       hcl_helpers.BlockRange(block),
 				blockType:       block.Type,
 			},
 			Mod: mod,
