@@ -2,10 +2,10 @@ package modconfig
 
 import (
 	"fmt"
+
 	"github.com/hashicorp/hcl/v2"
 	"github.com/spf13/viper"
 	"github.com/turbot/steampipe/pkg/constants"
-
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
@@ -45,7 +45,7 @@ type ResourceMaps struct {
 func NewModResources(mod *Mod) *ResourceMaps {
 	res := emptyModResources()
 	res.Mod = mod
-	res.Mods[mod.Name()] = mod
+	res.Mods[mod.GetInstallCacheKey()] = mod
 	return res
 }
 
@@ -83,16 +83,6 @@ func emptyModResources() *ResourceMaps {
 	}
 }
 
-// ModResourcesForQueries creates a ResourceMaps object containing just the specified queries
-// This is used to just create necessary prepared statements when executing batch queries
-func ModResourcesForQueries(queryProviders []QueryProvider, mod *Mod) *ResourceMaps {
-	res := NewModResources(mod)
-	for _, p := range queryProviders {
-		res.addControlOrQuery(p)
-	}
-	return res
-}
-
 // QueryProviders returns a slice of all QueryProviders
 func (m *ResourceMaps) QueryProviders() []QueryProvider {
 	res := make([]QueryProvider, m.queryProviderCount())
@@ -110,6 +100,22 @@ func (m *ResourceMaps) QueryProviders() []QueryProvider {
 	return res
 }
 
+// TopLevelResources returns a new ResourceMaps containing only top level resources (i.e. no dependencies)
+func (m *ResourceMaps) TopLevelResources() *ResourceMaps {
+	res := NewModResources(m.Mod)
+
+	f := func(item HclResource) (bool, error) {
+		if modTreeItem, ok := item.(ModTreeItem); ok && modTreeItem.GetMod().FullName == m.Mod.FullName {
+			res.AddResource(item)
+		}
+		return true, nil
+	}
+
+	m.WalkResources(f)
+
+	return res
+}
+
 func (m *ResourceMaps) Equals(other *ResourceMaps) bool {
 	//TODO use cmp.Equals or similar
 	if other == nil {
