@@ -3,18 +3,18 @@ package versionmap
 import (
 	"sort"
 
-	"github.com/Masterminds/semver"
+	"github.com/Masterminds/semver/v3"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
 // VersionListMap is a map keyed by dependency name storing a list of versions for each dependency
 type VersionListMap map[string]semver.Collection
 
-func (i VersionListMap) Add(name string, version *semver.Version) {
-	versions := append(i[name], version)
+func (m VersionListMap) Add(name string, version *semver.Version) {
+	versions := append(m[name], version)
 	// reverse sort the versions
 	sort.Sort(sort.Reverse(versions))
-	i[name] = versions
+	m[name] = versions
 
 }
 
@@ -23,7 +23,7 @@ func (m VersionListMap) FlatMap() map[string]bool {
 	var res = make(map[string]bool)
 	for name, versions := range m {
 		for _, version := range versions {
-			key := modconfig.ModVersionFullName(name, version)
+			key := modconfig.BuildModDependencyPath(name, version)
 			res[key] = true
 		}
 	}
