@@ -1,11 +1,9 @@
 import DashboardListEmptyCallToAction from "./DashboardListEmptyCallToAction";
-import ExternalLink from "./ExternalLink";
 import { ComponentsMap } from "../types";
 
 const buildComponentsMap = (overrides = {}): ComponentsMap => {
   return {
     DashboardListEmptyCallToAction,
-    ExternalLink,
     ...overrides,
   };
 };
